@@ -27,13 +27,27 @@ function (
 	par.list = NULL, 
 	eta.list = NULL, 
 	missing = -99, 
+	delay = 0,
 	...
 ){
     if (win())  grid <- FALSE
     if (win())  concurrent <- FALSE
     run <- unique(run)
-	    
+    if (missing(command)){
+    	message('argument "command" was not supplied')
+    	message('searching for NONMEM ...')
+    	candidate <- safe.call(findNonmemCommand,...)
+    	if(!length(candidate))stop('NONMEM not detected. Specify "command" directly or see help for findNonmemCommand.')
+    	if(length(candidate) > 1 ){
+    		message('found: ',paste(collapse=', ',candidate))
+    		candidate <- candidate[[1]]
+    	}
+    	#now candidate is length 1
+    	message('using command: ',candidate)
+    	command <- candidate
+    }    
     for (each in run) {
+    	Sys.sleep(delay/1000)
         args <- list(
 		run = each, 
 		command = command, 
@@ -66,8 +80,13 @@ function (
         if (concurrent){
             library(fork)
             suppressWarnings(handleSIGCLD())
-            pid <- fork(NULL)
+            pid <- fork::fork(NULL)
             if (pid == 0) {
+            
+            #library(multicore)
+            #pid <- multicore::fork()
+            #if(inherits(pid,'masterProcess'){
+            	    
                 tryCatch(
                 	do.call("runNonmem", args),
                 	error=function(e)warning(e$message,call.=FALSE,immediate.=TRUE)
@@ -111,6 +130,7 @@ NONR72 <- function(
 	par.list = NULL, 
 	eta.list = NULL, 
 	missing = -99, 
+	delay = 0,
 	...,
 	interface='autolog.pl',
 	q='all.q'
@@ -119,7 +139,7 @@ NONR72 <- function(
 	command=command,
 	project=project,
 	boot=boot,
-  grid=grid,
+	grid=grid,
 	concurrent=concurrent,
 	urgent=urgent,
 	udef=udef,
@@ -141,7 +161,8 @@ NONR72 <- function(
 	cat.cov=cat.cov,
 	par.list=par.list,
 	eta.list=eta.list,
-	missing=-99,
+	missing= missing,
+	delay = delay,
 	...,
 	interface=interface,
 	q=q
